==> keycloak-model-map-hot-rod-20.0.0-sources.jar: org/keycloak/models/map/storage/hotRod/group/HotRodGroupEntityDescriptor.java <==
package org.keycloak.models.map.storage.hotRod.group;
import org.infinispan.protostream.GeneratedSchema;
import java.util.function.Function;
public class HotRodGroupEntityDescriptor implements org.keycloak.models.map.storage.hotRod.common.HotRodEntityDescriptor<org.keycloak.models.map.storage.hotRod.group.HotRodGroupEntity, org.keycloak.models.map.storage.hotRod.group.HotRodGroupEntityDelegate> {
    @Override
    public Class<?> getModelTypeClass() {
        return org.keycloak.models.GroupModel.class;
    }
    @Override
    public Class<org.keycloak.models.map.storage.hotRod.group.HotRodGroupEntity> getEntityTypeClass() {
        return org.keycloak.models.map.storage.hotRod.group.HotRodGroupEntity.class;
    }
    @Override
    public String getCacheName() {
        return org.keycloak.models.map.storage.ModelEntityUtil.getModelName(org.keycloak.models.GroupModel.class);
    }
    @Override
    public Function<org.keycloak.models.map.storage.hotRod.group.HotRodGroupEntity, org.keycloak.models.map.storage.hotRod.group.HotRodGroupEntityDelegate> getHotRodDelegateProvider() {
        return org.keycloak.models.map.storage.hotRod.group.HotRodGroupEntityDelegate::new;
    }
    @Override
    public Integer getCurrentVersion() {
        return org.keycloak.models.map.storage.hotRod.group.HotRodGroupEntity.VERSION;
    }
    @Override
    public GeneratedSchema getProtoSchema() {
        return org.keycloak.models.map.storage.hotRod.group.HotRodGroupEntity.HotRodGroupEntitySchema.INSTANCE;
    }
}

==> keycloak-model-map-hot-rod-21.0.2-sources.jar: org/keycloak/models/map/storage/hotRod/group/HotRodGroupEntityDescriptor.java <==
package org.keycloak.models.map.storage.hotRod.group;
import org.infinispan.protostream.GeneratedSchema;
import java.util.function.Function;
@javax.annotation.processing.Generated("org.keycloak.models.map.processor.GenerateHotRodEntityImplementationsProcessor")
public class HotRodGroupEntityDescriptor implements org.keycloak.models.map.storage.hotRod.common.HotRodEntityDescriptor<org.keycloak.models.map.storage.hotRod.group.HotRodGroupEntity, org.keycloak.models.map.storage.hotRod.group.HotRodGroupEntityDelegate> {
    @Override
    public Class<?> getModelTypeClass() {
        return org.keycloak.models.GroupModel.class;
    }
    @Override
    public Class<org.keycloak.models.map.storage.hotRod.group.HotRodGroupEntity> getEntityTypeClass() {
        return org.keycloak.models.map.storage.hotRod.group.HotRodGroupEntity.class;
    }
    @Override
    public String getCacheName() {
        return org.keycloak.models.map.storage.ModelEntityUtil.getModelName(org.keycloak.models.GroupModel.class);
    }
    @Override
    public Function<org.keycloak.models.map.storage.hotRod.group.HotRodGroupEntity, org.keycloak.models.map.storage.hotRod.group.HotRodGroupEntityDelegate> getHotRodDelegateProvider() {
        return org.keycloak.models.map.storage.hotRod.group.HotRodGroupEntityDelegate::new;
    }
    @Override
    public Integer getCurrentVersion() {
        return org.keycloak.models.map.storage.hotRod.group.HotRodGroupEntity.VERSION;
    }
    @Override
    public GeneratedSchema getProtoSchema() {
        return org.keycloak.models.map.storage.hotRod.group.HotRodGroupEntity.HotRodGroupEntitySchema.INSTANCE;
    }
}
